pub trait GuidedElement<T: Ord> {
// Required method
fn guide(&self) -> T;
}Expand description
Defines a guided element. The element provides a guide function used by the priority queue.
pub trait GuidedElement<T: Ord> {
// Required method
fn guide(&self) -> T;
}Defines a guided element. The element provides a guide function used by the priority queue.